@@ -8,7 +8,7 @@ library(fdaPDE)
 data(mesh.2D.simple)
 observations = sin(pi*mesh.2D.simple$nodes[,1]) + rnorm(n = nrow(mesh.2D.simple$nodes), sd = 0.1)
 
-FEMbasis = create.FEM.basis(mesh.2D.simple, 2)
+FEMbasis = create.FEM.basis(mesh.2D.simple)
 
 lambda = c(10^-2, 10^-1, 0.5, 5, 10)
 
